@@ -282,11 +282,12 @@ crew_test("crew_controller_local() resource usage metric logging", {
     crew_test_sleep()
   })
   x$start()
-  x$push(Sys.sleep(2))
+  x$push(name = "monitored_task", Sys.sleep(2))
   x$wait(mode = "all", seconds_timeout = 30)
   x$terminate()
   expect_true(dir.exists(log))
   data <- autometric::log_read(log)
+  expect_true(any("monitored_task" %in% data$phase))
   expect_true(is.data.frame(data))
   expect_gt(nrow(data), 0L)
   expect_equal(unique(data$status), 0L)
